Unit-cell visualization settings
These options style the unit-cell box and crystallographic axis arrows used by the cell growth modes (symmetryMode: 'cell' / 'fragment-cell').
These options style the unit-cell box and crystallographic axis arrows used by the cell growth modes (symmetryMode: 'cell' / 'fragment-cell').
| Option | Type | Default | Description |
|---|---|---|---|
cell.boxColor | Color | "#000000" | Unit-cell edge colour. |
cell.boxOpacity | Number | 0.8 | Unit-cell edge opacity. |
cell.boxLineWidth | Number | 2 | Unit-cell edge line width. |
cell.arrowColorA | Color | "#E74C3C" | Colour of the a axis arrow. |
cell.arrowColorB | Color | "#2ECC71" | Colour of the b axis arrow. |
cell.arrowColorC | Color | "#3498DB" | Colour of the c axis arrow. |
cell.arrowHeadLengthMult | Number | 0.05 | Arrow-head length multiplier. |
cell.arrowHeadWidthMult | Number | 0.25 | Arrow-head width multiplier. |
cell.arrowCylinderRadius | Number | 0.04 | Axis-arrow shaft radius. |