Hydrogen bond visualization settings
These options control the appearance of hydrogen bonds (drawn as dashed cylinders) in the 3D structure.
These options control the appearance of hydrogen bonds (drawn as dashed cylinders) in the 3D structure.
| Option | Type | Default | Description |
|---|---|---|---|
hbondRadius | Number | 0.04 | Radius of hydrogen bond cylinders. |
hbondColor | Color | "#AAAAAA" | Default color for hydrogen bonds. |
hbondColorRoughness | Number | 0.3 | Roughness of hydrogen bond material (0–1). |
hbondColorMetalness | Number | 0.1 | Metalness of hydrogen bond material (0–1). |
hbondDashSegmentLength | Number | 0.3 | Target length for each dash+gap segment. |
hbondDashFraction | Number | 0.6 | Fraction of each segment that is solid (vs gap). |