Skip to content

Interaction settings

These options control how users interact with the 3D structure. The raycast thresholds determine how forgiving clicking/tapping on thin geometry is; touch thresholds are larger than mouse thresholds by default.

OptionTypeDefaultDescription
interaction.rotationSpeedNumber5Speed of rotation when dragging.
interaction.lockRotationBooleanfalseDisables mouse and one-finger rotation gestures. Explicit view changes still apply.
interaction.lockZoomBooleanfalseDisables mouse-wheel and pinch zoom gestures. Explicit view changes still apply.
interaction.clickThresholdNumber200Maximum time in milliseconds for an interaction to be considered a click.
interaction.mouseRaycast.lineThresholdNumber0.5Threshold for line selection with the mouse.
interaction.mouseRaycast.pointsThresholdNumber0.5Threshold for point selection with the mouse.
interaction.mouseRaycast.meshThresholdNumber0.1Threshold for mesh selection with the mouse.
interaction.touchRaycast.lineThresholdNumber2Threshold for line selection with touch.
interaction.touchRaycast.pointsThresholdNumber2Threshold for point selection with touch.
interaction.touchRaycast.meshThresholdNumber0.2Threshold for mesh selection with touch.