Skip to content

Selection settings

These options control the behavior and appearance of atom and bond selections. Selection events reach your code through viewer.selections.onChange(callback) — see CrystalViewer.

OptionTypeDefaultDescription
selection.modeString"multiple"Selection mode, either single or multiple.
selection.markerMultNumber1.3Size multiplier for atom selection markers.
selection.bondMarkerMultNumber1.7Size multiplier for bond selection markers.
selection.haloWidthNumber4Visible width in CSS pixels of the 2D atom selection halo beyond the normal publication outline.
selection.highlightEmissiveNumber (hex)11184810Emissive color value for highlighted selections.
selection.markerColorsArray[2062260, 16744206, 2924588, 14034728, 9725885, 9197131, 14907330, 8355711, 12369186, 1556175]Array of colors (hex values) used for selection markers; a cycle of 10 different colors by default.