Interaction settings
These options control how users interact with the 3D structure. The raycast thresholds determine how forgiving clicking/tapping on thin geometry is; touch thresholds are larger than mouse thresholds by default.
These options control how users interact with the 3D structure. The raycast thresholds determine how forgiving clicking/tapping on thin geometry is; touch thresholds are larger than mouse thresholds by default.
| Option | Type | Default | Description |
|---|---|---|---|
interaction.rotationSpeed | Number | 5 | Speed of rotation when dragging. |
interaction.lockRotation | Boolean | false | Disables mouse and one-finger rotation gestures. Explicit view changes still apply. |
interaction.lockZoom | Boolean | false | Disables mouse-wheel and pinch zoom gestures. Explicit view changes still apply. |
interaction.clickThreshold | Number | 200 | Maximum time in milliseconds for an interaction to be considered a click. |
interaction.mouseRaycast.lineThreshold | Number | 0.5 | Threshold for line selection with the mouse. |
interaction.mouseRaycast.pointsThreshold | Number | 0.5 | Threshold for point selection with the mouse. |
interaction.mouseRaycast.meshThreshold | Number | 0.1 | Threshold for mesh selection with the mouse. |
interaction.touchRaycast.lineThreshold | Number | 2 | Threshold for line selection with touch. |
interaction.touchRaycast.pointsThreshold | Number | 2 | Threshold for point selection with touch. |
interaction.touchRaycast.meshThreshold | Number | 0.2 | Threshold for mesh selection with touch. |