Selection settings
These options control the behavior and appearance of atom and bond selections. Selection events reach your code through viewer.selections.onChange(callback) — see CrystalViewer.
These options control the behavior and appearance of atom and bond selections. Selection events reach your code through viewer.selections.onChange(callback) — see CrystalViewer.
| Option | Type | Default | Description |
|---|---|---|---|
selection.mode | String | "multiple" | Selection mode, either single or multiple. |
selection.markerMult | Number | 1.3 | Size multiplier for atom selection markers. |
selection.bondMarkerMult | Number | 1.7 | Size multiplier for bond selection markers. |
selection.haloWidth | Number | 4 | Visible width in CSS pixels of the 2D atom selection halo beyond the normal publication outline. |
selection.highlightEmissive | Number (hex) | 11184810 | Emissive color value for highlighted selections. |
selection.markerColors | Array | [2062260, 16744206, 2924588, 14034728, 9725885, 9197131, 14907330, 8355711, 12369186, 1556175] | Array of colors (hex values) used for selection markers; a cycle of 10 different colors by default. |